# Change Log

## v0.0.1 (2/3/2021)
- First Release

## v0.1.0 (2/9/2021)
- Support for new security measure in ZapURL
- Custom URL Shortening enabled
- Package Build Version and Info
- Latest version function
- Shows Official Site Function


## v0.1.1 (2/9/2021)
- Bug fixed where classic short could display extra `<` character at end resulting in link issues.
